\name{escort}
\alias{escort}
\alias{escortHtmlOutput}

\title{
    ESCORT (Expert System for Characterization Of Rock Types) of \emph{Pearce (1987)}
}

\description{
    This is an implementation of the ESCORT expert system software package \emph{Pearce 1987} aiming to identify the eruptive setting of a 
    volcanic rock sample. The system takes into account specialist knowledge on the geological setting, mineralogy, petrology and geochemistry 
    of igneous rocks, the latter based on compilation of a large body of high-quality data from known settings.
}

\usage{
    escort(elconc, geolobs, geolmb, minobs, petobs)
    escortHtmlOutput(mat, title = "escoRt results")
    .escortTcl()
}

\arguments{
  \item{elconc}{Elemental concentrations}
  \item{geolobs}{Geological observations}
  \item{geolmb}{Corresponding measures of belief (0-1), 1 = maximal confidence}
  \item{minobs}{Mineral observations}
  \item{petobs}{Petrologic observations}
  \item{mat}{The output of the main \code{escort} function}
  \item{title}{Title of the html window with the output}
}

\details{
This expert system assigns an lava of unknown affinity to its most probable tectonic setting of eruption on the basis of the following parameters:

1. The content of one or more of the immobile elements:
 
    Ti, Zr, Y, Nb, P and Cr

2. The geological environment of the lava sequence: 

    Terrestrial, Shoreline, Shelf, Reef, Turbidite, Pelagic, Pillowed Flows, Sheet Flows, Non-sheet Flows, 
    Pyroclastics, Sheeted Dykes, Sediments, Cryst. Basement, Int-acid Pluton, Basic Pluton, Other Volcanic, Thrust

3. The phenocrysts present in the lavas:

    Plagioclase, Clinopyroxene, Olivine, Orthopyroxene, Amphibole, Mica, Quartz, Feldspathoid, K-feldspar   

4. The petrological characteristics of the lavas: 
    
    Fe enrichment/the lack thereof   
    
    
    \bold{Possible geotectonic settings recognized by Escort:}
    \tabular{lll}{ 
        \bold{Abbrev.} \tab \bold{Description} \cr 
        N-OR \tab Mature oceanic spreading centre of "normal" bathymetry not associated with subduction   \cr
        P-OR \tab Oceanic spreading centre showing bathymetric evidence of plume influence  \cr
        I-OR \tab Incipient spreading centre < 500 km from a continental margin \cr
        B-OR \tab Spreading centre in a back-arc or inter-arc setting \cr
        F-OR \tab Spreading centre forming fore-arc basin crust, either by fore-arc \cr
        \tab spreading or spreading prior to arc development \cr
        O-VA \tab Volcanic arc developed on oceanic lithosphere  \cr
        C-VA \tab Volcanic arc developed on continental lithosphere \cr
        CZ \tab Post-collision settings, including post-collision rift terranes \cr
        O-WP \tab Intraplate volcanism on oceanic lithosphere \cr
        C-WP \tab Intraplate volcanism on continental lithosphere excluding strongly attenuated terranes (beta values >3)\cr
        N-CF \tab Continental flood basalt terrains and zones of strong attenuation not subduction-related \cr
        B-CF \tab Continental flood basalt terrains and zones of strong attenuation associated with subduction \cr    
    }
    
    \tabular{lll}{ 
        \bold{Abbrev.} \tab \bold{Examples} \cr 
        N-OR \tab Mid-Atlantic Ridge (63); East-Pacific Rise (20); Costa-Rica Rift (48); Carlsberg R. (6); \cr
        \tab Galapagos Rise (39); Pacific-Antarctic Ridge (56) \cr
        P-OR \tab Iceland area (86); Azores area (60); Tristan area (35); Bouvet area (50) \cr
        I-OR \tab Atlantic margin (36); Red Sea/Gulf of Aden (5); Gulf of California (24) \cr
        B-OR \tab Shikoku Basin (40); Scotia Sea (20); Tyrrhenian Sea (2) \cr
        F-OR \tab No extant examples; O-VA data base used. \cr
        O-VA \tab New Britain (163); Izu-Marianas (27); L. Antilles (127); N. Ireland(59); S. Sandwich Is.(10); \cr
        \tab Tonga-Kermadec (10); Singihe-Halmahera (23) \cr
        C-VA \tab Andes (48); Cascades (7); Aegean (20); C. America (23); Aeolian arc (31); Sunda arc (43) \cr
        CZ \tab Papua-New Guinea (98); Alps (43); China (2); Italy (33) \cr
        O-WP \tab Hawaii-Emperor seamounts (111); other Pacific Is. (44); Indian Ocean/Red Sea Is. (59); \cr
        \tab Atlantic Is. (150) \cr
        C-WP \tab African Rift (185); Libya/Sudan (30); Cameroon Line (140); Europe (31); S. New Zealand (21); \cr
        \tab Australia (26) \cr
        N-CF \tab British Tertiary Province (28); E. Greenland (33); Morocco (17); Parana (53); Deccan (24); \cr
        \tab Arabia/Afar (46) \cr
        B-CF \tab Patagonia (44); Bransfield St. (21); N. Zealand (63); Manchuria (45) \cr    
    }
}
 
\value{
    The \code{escort} function returns a list \code{results} with the following items:
    \item{Geotectonic Setting}{a list of possible geotectonic settings, with corresponding probabilities and final decision regarding the 
        likely and unlikely settings.}
    \item{Magma Type}{a list of possible magma environments (OR, VA, CZ, WP, CF), with corresponding probabilities and final decision.}
    \item{Rock Type}{a list of possible rock types (basic, intermediate, evolved), with corresponding probabilities and final decision.}
    
    The final decision of the EscoRt expert system is displayed by a series of symbols where:
    
    *** = Likely Setting\cr
    **  = Probable Setting\cr
    *   = Possible Setting\cr
    ooo = Unlikely Setting\cr 
    
    \code{escortHtmlOutput} is a utility function showing the result in the HTML format (in a web browser).    
}

\references{
    Pearce JA (1987) An expert system for the tectonic characterization of ancient volcanic rocks. J Volcanol geotherm Res 32:51-65
    \href{http://dx.doi.org/10.1016/0377-0273(87)90036-9}{doi:10.1016/0377-0273(87)90036-9}
}

\author{
    Julian Pearce, \email{PearceJA@cardiff.ac.uk}

    R version: Vojtech Janousek, \email{vojtech.janousek@geology.cz}
}


\examples{
    # Loading some arbitrary data to get the plugin sourced
    data(sazava)
    accessVar("sazava")
    
    # Lorne lava as an example (Pearce 1987)   
    # Concentrations 
    elconc<-c(1.27,198,20.8,14.3,0.36,260)
    names(elconc)<-c("TiO2","Zr","Y","Nb","P2O5","Cr")
    
    # Geological constraints
    geolobs<-c("Terrestrial","Non-sheet Flows","Cryst. Basement")
    geolmb<-c(0.95,0.95,0.95) # Measures of belief (0-1), 1 = maximal confidence
    names(geolmb)<-geolobs

    # Petrologic constraints
    petobs<-"No Fe enricht."
    petmb<-1
    names(petmb)<-petobs

    # Mineralogic constraints:
    minobs<-c("Clinopyroxene","Olivine") 
    minmb<-c(1,1)
    names(minmb)<-minobs
    results<-escort(elconc=elconc,geolobs=geolobs,geolmb=geolmb,minobs=minobs,petobs=petobs)
    
    escortHtmlOutput(results) # HTML output
    
    .escortTcl() # GUI
}

\keyword{manip}
\concept{Geotectonic}
\concept{Calculation}
\concept{Menu: Plugins}
\concept{Plugin: EscoRt}
